# Android Versions

You can run the following versions on Android:

`toolmate` - full version, the same as the one created for Windows / macOS / Linux / ChromeOS

`toolmate_android` - light version that supports `groq`, `ollama`, `chatgpt` backends and `letmedoit` mode, created to work with Termux:API.

For setup, read https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Termux%20Setup.md